"""
Script for producing climatologies from reformatted argo data.
Input:
Reformnatted raw data from the argo floats
Output:
Time series and climatology of a particular variable, in netCDF format. This includes the mean, minimum and maximum of each grid cell

Author: Marcus Falls marcus.falls@bsc.es
Date: 11/02/2019
"""

from netCDF4 import Dataset
import numpy as np
import os
import datetime
import time
import struct

from math import sqrt
from datetime import datetime as DATETIME
from geopy import distance
import numpy.ma as ma
import pandas as pd
from numpy import median
from numpy import mean

def make_ts(source, destination, mask, model, varname, sensors=None, sensorcat=None):

    # inputs:
    #
    # source: path of input files
    # destination: where the netcdf will go
    # mask: netCDF file containing grid and mask data
    # model: name of model, for now either 'nemo' or 'pisces'
    # sensordata: a csv file containing info on sensors
    # output: a netcdf file of the climatologies

    def getmonths(start, end):
        months = [start]
        monthinds = [[] for i in range(12)]
        curr = start
        count = 0
        while curr != end:

            # for i in range(200):
            m = int(curr[4:])
            y = int(curr[:-2])
            monthinds[m - 1].append(count)
            count = count + 1
            m = m + 1
            if m == 13:
                m = 1
                y = y + 1
            curr = "%04d" % y + "%02d" % m
            months.append(curr)
        return months, monthinds

    def mindistcoords(lat, lon, latitudes, longitudes):
        s=time.time()
        mindist = 20000
        minI = 0
        minJ = 0

        (x,y)=np.shape(latitudes)

        for I in range(len(latitudes[0])):
            for J in range(len(latitudes[:, 0])):
                if abs(lat-latitudes[J][I])<2 and abs(lon-longitudes[J][I])<2:
                    dist = distance.distance((lat, lon), (latitudes[J][I], longitudes[J][I]))
                    if dist < mindist:
                        mindist = dist
                        minI = I
                        minJ=J

        #print('new',minJ,minI,mindist,lat,lon,latitudes[minJ][minI],longitudes[minJ][minI])
        e = time.time()
        #print(e-s)
        return minJ, minI

    def makeinds(obs, ref):
        mids = []
        for i in range(len(ref) - 1):
            mids.append((ref[i + 1] + ref[i]) / 2)
        res = []
        ind = 0
        check = mids[ind]
        for i in obs:
            # print(i,check,ind)
            if np.isnan(i):
                #res.append(np.nan)
                break
            else:

                while i > check and ind != len(mids) - 1:
                    ind = ind + 1  ### change this line
                    check = mids[ind]
                res.append(ind)
        return res

        ## number of months and determining variable from the filename

    def getsensors(file, category):
        # input: csv file of metadata containing info in sensors, heading of category of interest
        # output: dictionary of floats a categories
        data = pd.read_csv(file)

        sensorcategories = {}
        for i in range(len(data['floats'])):
            if data[category][i] != '0':
                if data[category][i] not in sensorcategories.keys():
                    sensorcategories[data[category][i]] = []
                sensorcategories[data[category][i]].append(data['floats'][i])
        return sensorcategories

    files=os.listdir(source)
    files.sort()
    first=files[0]

    smonth=first[-9:-3]
    fmonth=files[-1][-9:-3]
    months,monthinds=getmonths(smonth,fmonth)

    ## extracting the dimensions, latitudes, latitudes and levels from the mask file so that the output has the same attributes
    maskdata=Dataset(mask,'r')
    X=maskdata.dimensions['x'].size
    Y=maskdata.dimensions['y'].size
    if 'z' in maskdata.dimensions:
        Z = maskdata.dimensions['z'].size
    elif 'deptht' in maskdata.dimensions:
        Z=maskdata.dimensions['deptht'].size ## pisces=deptht, nemo=z

    gridlats = np.array(maskdata.variables['nav_lat'])
    gridlons = np.array(maskdata.variables['nav_lon'])
    if 'nav_lev' in maskdata.variables:
        gridlvls = np.array(maskdata.variables['nav_lev']) ## pisces=deptht, nemo=z
    elif 'deptht' in maskdata.variables:
        gridlvls = np.array(maskdata.variables['deptht'])

    ### if the model netcdf has bathymetry data, this is used to create a mask
    depths = np.zeros((len(months), Z, Y, X))
    if model=='nemo':  ### nemo outputs use a variable called bathymetry, the depth at each gridpoint
        if 'mbathy' in maskdata.variables and bathymetry==1:
            ismask=1
            gridmask= np.array(maskdata.variables['mbathy'])[0]

            for t in range(len(months)):
                for x in range(X):
                    for y in range(Y):
                        depth = gridmask[y][x]
                        for z in range(len(gridlvls)):
                            if gridlvls[z] < depth:
                                depths[t, z, y, x] = 1
                            else:
                                break
        else:
            gridmask = None
            ismask=0

    if model=='pisces': ### pisces uses NaN for all land points
        if 'NCHL' in maskdata.variables and bathymetry==1: ## this may need to be changed

            ismask = 1
            gridmask = np.array(maskdata.variables['NCHL'])[0]

            for x in range(X):
                for y in range(Y):
                    for z in range(len(gridlvls)):

                        if gridmask[z,y,x]!=100000002004087734272:
                            depths[0, z, y, x] = 1
                        else:
                            break
            for t in range(1,len(months)):
                depths[t, :, :, :] = depths[0, :, :, :]

            print('mask of land values created')
        else:
            gridmask = None
            ismask = 0
            print('no mask of land values created')

    if sensors:
        varcategories=getsensors(sensors, sensorcat)

    # inserting the data into the netcdf
    os.chdir(source)

    ## dictionary of array for means, number of measurements,
    vars={}
    # for all data
    vars['numbersall'] = np.zeros((len(months), Z, Y, X))
    vars['profilesall'] = np.zeros((len(months), Z, Y, X))
    # for each sensor
    if sensors:
        for key in varcategories.keys():
            vars['numbers' + key] = np.zeros((len(months), Z, Y, X))
            vars['profiles' + key] = np.zeros((len(months), Z, Y, X))

    ### dictionaries of lists of data entries in each grid cell
    dict={}
    dict['alltimes']={} # to make time series
    dict['allmonth']={} # to make climatologies

    if sensors:
        for key in varcategories.keys():
            dict[key+'times'] = {}
            dict[key+'month'] = {}

    for month in range(len(months)):
        f=varname+'_'+str(months[month])+'.nc'
        print(str(month) + ' extracting')
        for i in range(len(monthinds)):
            if month in monthinds[i]:
                monthind=i
        # if month==60:
        #     break
        if f in files:
            dataold = Dataset(f, 'r')

            ## exctracting  the old variable data.
            varold_adj = np.array(dataold.variables[varname+'_adjusted'])
            varold = np.array(dataold.variables[varname])
            varold_adj_qc = np.array(dataold.variables[varname+'_adjusted_qc'])
            varold_qc = np.array(dataold.variables[varname+'_qc'])

            # taking each element of the raw data, replacing with adjusted if there is any,
            # and replacing with NaN if the qc flag is 4

            for d in range(len(varold)):
                for fl in range(len(varold[d])):
                    if not np.isnan(varold[d][fl][0]):
                        for p in range(len(varold[d][fl])):
                        #if varold[d][fl][p]!=np.nan:
                            if not np.isnan(varold_adj[d][fl][p]):
                                if varold_adj_qc[d][fl][p]!=4:
                                    varold[d][fl][p]=varold_adj[d][fl][p]
                                else:
                                    varold[d][fl][p] = np.nan
                            else:
                                if varold_qc[d][fl][p] == 4:
                                    varold[d][fl][p] = np.nan

            ## rest of process starts here
            floatsold=np.array(dataold.variables['floats'])
            latsold = np.array(dataold.variables['latitude'])
            lonsold = np.array(dataold.variables['longitude'])
            presold = np.array(dataold.variables['pressure'])

            for day in range(len(varold)):
                for fl in range(len(varold[day])):
                    if not np.isnan(varold[day][fl][0]):

                        (indy,indx)=mindistcoords(latsold[day,fl], lonsold[day,fl], gridlats, gridlons) ### this needs sped up
                        vars['profilesall'][month, :, indy, indx] = vars['profilesall'][month, :, indy, indx] + 1
                        if sensors:
                            for key in varcategories.keys():
                                if floatsold[fl] in varcategories[key]:
                                    vars['profiles'+key][month, :, indy, indx] = vars['profiles'+key][month, :, indy, indx] + 1
                        inds=makeinds(presold[day][fl],gridlvls)
                        for meas in range(len(inds)):

                            if not np.isnan(varold[day][fl][meas]):
                                lvl=inds[meas]

                                vars['numbersall'][month,lvl,indy,indx]=vars['numbersall'][month,lvl,indy,indx]+1

                                if str(month)+'-'+str(lvl)+'-'+str(indy)+'-'+str(indx) in dict['alltimes'].keys():
                                    dict['alltimes'][str(month)+'-'+str(lvl)+'-'+str(indy)+'-'+str(indx)].append(varold[day][fl][meas])
                                else:
                                    dict['alltimes'][str(month) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx)]=[varold[day][fl][meas]]

                                if str(monthind)+'-'+str(lvl)+'-'+str(indy)+'-'+str(indx) in dict['allmonth'].keys():
                                    dict['allmonth'][str(monthind)+'-'+str(lvl)+'-'+str(indy)+'-'+str(indx)].append(varold[day][fl][meas])
                                else:
                                    dict['allmonth'][str(monthind) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx)]=[varold[day][fl][meas]]

                                # data sorted by sensor type
                                if sensors:
                                    for key in varcategories.keys():
                                        if floatsold[fl] in varcategories[key]:

                                            vars['numbers'+key][month, lvl, indy, indx] = vars['numbers'+key][month, lvl, indy, indx] + 1

                                            if str(month) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx) in dict[key+'times'].keys():
                                                dict[key+'times'][str(month) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx)].append(varold[day][fl][meas])
                                            else:
                                                dict[key+'times'][str(month) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx)] = [varold[day][fl][meas]]

                                            if str(monthind) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx) in dict[key+'month'].keys():
                                                dict[key+'month'][str(monthind) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx)].append(varold[day][fl][meas])
                                            else:
                                                dict[key+'month'][str(monthind) + '-' + str(lvl) + '-' + str(indy) + '-' + str(indx)] = [varold[day][fl][meas]]

            dataold.close()

        print(str(month) + ' complete')
            ## rest of process above

    print('all data extracted and binned')

    ## create dataset of time series and define global attributes

    os.chdir(destination)

    datanew = Dataset(varname +'_'+model+ '_ts.nc', 'w', format='NETCDF4_CLASSIC')

    datanew.title = 'Monthly climatology for '+varname+' in '+model+' grid'
    datanew.history = 'Created ' + datetime.datetime.now().strftime("%Y-%m-%d_%H:%M:%S")
    datanew.description = 'Gridded time series'
    datanew.references = "http://www.argodatamgt.org/Documentation"
    datanew.sources = 'Argo floats maintained by the following institutions: aoml, bodc, coriolis, csio, csiro, incois, jma, kma, kordi, meds'

    print('Dataset ' + varname + '_' + model + '_ts.nc created')

    ## create dimensions
    x = datanew.createDimension('x', X)  # latitude in degrees. Currently 1deg resolution (maybe change to make more flexible?)
    y = datanew.createDimension('y', Y)  # longitude in degrees. Currently 1deg resolution (maybe change to make more flexible?)
    z = datanew.createDimension('z', Z) # pressure/depth. need to agree on a suitable range
    t = datanew.createDimension('t', len(months))  # resolution in months. Months with no data will be included as nan arrays.

    ## create variables

    if ismask==1:
        dmask = datanew.createVariable('dmask', np.float32, ('t','z','y','x'), fill_value=np.nan)
        dmask.description="sea=0,land/under sea=1"
        dmask[:,:,:,:]=depths

    lvl_pres = datanew.createVariable('lvl_pres', np.float32, ('z','y','x'), fill_value=np.nan)
    lvl_pres.description="the pressure at each gridpoint"

    varsncdf={}

    varsncdf['all_profiles'] = datanew.createVariable('all_profiles', np.int32, ('t', 'z', 'y', 'x'),fill_value=0)

    fill=0
    print('land values set as ' + str(fill))

    varsncdf['all_median'] = datanew.createVariable('all_median', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
    varsncdf['all_mean']=datanew.createVariable('all_mean', np.float32, ('t','z','y','x'), fill_value=np.nan)
    varsncdf['all_max'] = datanew.createVariable('all_max', np.float32, ('t', 'z', 'y', 'x'),fill_value=np.nan)
    varsncdf['all_min'] = datanew.createVariable('all_min', np.float32, ('t', 'z', 'y', 'x'),fill_value=np.nan)
    varsncdf['all_measures'] = datanew.createVariable('all_measures', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)

    if ismask==1:
        maskarray=np.empty((len(months),Z,Y,X))
        maskarray[:]=np.nan
        maskarray = ma.masked_where(depths == False, maskarray)
        ma.set_fill_value(maskarray, fill)
        maskarray = maskarray.filled()
        varsncdf['all_median'][:, :, :, :] = maskarray
        varsncdf['all_mean'][:, :, :, :] = maskarray
        varsncdf['all_max'][:, :, :, :] = maskarray
        varsncdf['all_min'][:, :, :, :] = maskarray
        varsncdf['all_measures'][:, :, :, :] = maskarray

    for dictkey in dict['alltimes'].keys():
        [a, b, c, d] = [int(i) for i in dictkey.split('-')]
        varsncdf['all_median'][a, b, c, d]=median(dict['alltimes'][dictkey])
        varsncdf['all_mean'][a, b, c, d] = mean(dict['alltimes'][dictkey])
        varsncdf['all_max'][a, b, c, d] = max(dict['alltimes'][dictkey])
        varsncdf['all_min'][a, b, c, d] = min(dict['alltimes'][dictkey])
        varsncdf['all_measures'][a, b, c, d] = len(dict['alltimes'][dictkey])

    if sensors:
        for key in varcategories.keys():

            varsncdf[key +'_profiles'] = datanew.createVariable(key + '_profiles', np.int32, ('t', 'z', 'y', 'x'), fill_value=0)

            varsncdf[key + '_median'] = datanew.createVariable(key + '_median', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_mean'] = datanew.createVariable(key + '_mean', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_max'] = datanew.createVariable(key + '_max', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_min'] = datanew.createVariable(key + '_min', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_measures'] = datanew.createVariable(key + '_measures', np.float32, ('t', 'z', 'y', 'x'),fill_value=np.nan)

            if ismask == 1:
                varsncdf[key+'_median'][:, :, :, :] = maskarray
                varsncdf[key + '_mean'][:, :, :, :] = maskarray
                varsncdf[key + '_max'][:, :, :, :] = maskarray
                varsncdf[key + '_min'][:, :, :, :] = maskarray
                varsncdf[key + '_measures'][:, :, :, :] = maskarray

            for dictkey in dict[key+'times'].keys():
                [a, b, c, d] = [int(i) for i in dictkey.split('-')]
                varsncdf[key + '_median'][a, b, c, d] = median(dict[key + 'times'][dictkey])
                varsncdf[key + '_mean'][a, b, c, d] = mean(dict[key + 'times'][dictkey])
                varsncdf[key + '_max'][a, b, c, d] = max(dict[key + 'times'][dictkey])
                varsncdf[key + '_min'][a, b, c, d] = min(dict[key + 'times'][dictkey])
                varsncdf[key + '_measures'][a, b, c, d] = len(dict[key + 'times'][dictkey])

    vars['profilesallnew'] = vars['profilesall'][:, :, :, :]
    if sensors:
        for key in varcategories.keys():
            vars['profiles'+key+'new'] = vars['profiles'+key][:, :, :, :]

    if ismask==1:

        vars['profilesallnew'] = ma.masked_where(depths == False, vars['profilesallnew'])
        ma.set_fill_value(vars['profilesallnew'], fill)
        vars['profilesallnew'] = vars['profilesallnew'].filled()

        if sensors:
            for key in varcategories.keys():
                vars['profiles'+key+'new'] = ma.masked_where(depths == False, vars['profiles'+key+'new'])
                ma.set_fill_value(vars['profiles'+key+'new'], fill)
                vars['profiles'+key+'new'] = vars['profiles'+key+'new'].filled()

    varsncdf['all_profiles'][:, :, :, :] = vars['profilesallnew']

    if sensors:
        for key in varcategories.keys():
            varsncdf[key + '_profiles'][:, :, :, :] = vars['profiles' + key + 'new']

    latitude=datanew.createVariable('nav_lat', np.float32, ('y','x'), fill_value=np.nan)
    latitude[:,:] = gridlats
    latitude.axis = 'x'

    longitude = datanew.createVariable('nav_lon', np.float32, ('y', 'x'), fill_value=np.nan)
    longitude[:,:] = gridlons
    longitude.axis='y'

    level = datanew.createVariable('nav_lev', np.float32, ('z',), fill_value=np.nan)
    level[:] = gridlvls
    level.axis = 'z'

    times = datanew.createVariable('times', np.int32, ('t',))
    times[:] = months
    times.axis = 't'

    ## create climatologies

    dataclim = Dataset(varname +'_'+model+  '_climatology.nc', 'w', format='NETCDF4_CLASSIC')

    dataclim.title = 'Monthly climatology for '+varname
    dataclim.history = 'Created ' + datetime.datetime.now().strftime("%Y-%m-%d_%H:%M:%S")
    dataclim.description = 'Gridded climatologies'
    dataclim.references = "http://www.argodatamgt.org/Documentation"
    dataclim.sources = 'Argo floats maintained by the following institutions: aoml, bodc, coriolis, csio, csiro, incois, jma, kma, kordi, meds'

    print('Dataset ' + varname + '_'+model+'_climatology.nc created')

    ## create dimensions
    x = dataclim.createDimension('x', X)  # latitude in degrees. Currently 1deg resolution (maybe change to make more flexible?)
    y = dataclim.createDimension('y', Y)  # longitude in degrees. Currently 1deg resolution (maybe change to make more flexible?)
    z = dataclim.createDimension('z', Z) # pressure/depth. need to agree on a suitable range
    t = dataclim.createDimension('t', 12)  # resolution in months. Months with no data will be included as nan arrays.

    ## create variables
    if ismask==1:
        dmask = dataclim.createVariable('dmask', np.float32, ('t','z','y','x'), fill_value=np.nan)
        dmask.description="sea=1,land=0"
        depths=depths[:12,:,:,:]
        dmask[:,:,:,:]=depths

    lvl_pres = dataclim.createVariable('lvl_pres', np.float32, ('z','y','x'), fill_value=np.nan)
    lvl_pres.description = "the pressure at each gridpoint"

    varsncdf['all_profiles'] = dataclim.createVariable('all_profiles', np.int32, ('t', 'z', 'y', 'x'),fill_value=0)

    varsncdf['all_median'] = dataclim.createVariable('all_median', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
    varsncdf['all_mean'] = dataclim.createVariable('all_mean', np.float32, ('t','z','y','x'), fill_value=np.nan)
    varsncdf['all_max'] = dataclim.createVariable('all_max', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
    varsncdf['all_min'] = dataclim.createVariable('all_min', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
    varsncdf['all_measures'] = dataclim.createVariable('all_measures', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)

    if ismask==1:
        maskarray=np.empty((12,Z,Y,X))
        maskarray[:]=np.nan
        maskarray = ma.masked_where(depths == False, maskarray)
        ma.set_fill_value(maskarray, fill)
        maskarray = maskarray.filled()
        varsncdf['all_median'][:,:,:,:] = maskarray
        varsncdf['all_mean'][:, :, :, :] = maskarray
        varsncdf['all_max'][:, :, :, :] = maskarray
        varsncdf['all_min'][:, :, :, :] = maskarray
        varsncdf['all_measures'][:, :, :, :] = maskarray

    for dictkey in dict['allmonth'].keys():
        [t, z, y, x] = [int(i) for i in dictkey.split('-')]
        varsncdf['all_median'][t, z, y, x] = median(dict['allmonth'][dictkey])
        varsncdf['all_mean'][t, z, y, x] = mean(dict['allmonth'][dictkey])
        varsncdf['all_max'][t, z, y, x] = max(dict['allmonth'][dictkey])
        varsncdf['all_min'][t, z, y, x] = min(dict['allmonth'][dictkey])
        varsncdf['all_measures'][t, z, y, x] = len(dict['allmonth'][dictkey])

    varsncdf['all_median'] = ma.masked_where(depths == False, varsncdf['all_median'])
    varsncdf['all_mean'] = ma.masked_where(depths == False, varsncdf['all_mean'])
    varsncdf['all_max'] = ma.masked_where(depths == False, varsncdf['all_max'])
    varsncdf['all_min'] = ma.masked_where(depths == False, varsncdf['all_min'])
    varsncdf['all_measures'] = ma.masked_where(depths == False, varsncdf['all_measures'])

    ma.set_fill_value(varsncdf['all_median'], fill)
    ma.set_fill_value(varsncdf['all_mean'], fill)
    ma.set_fill_value(varsncdf['all_max'], fill)
    ma.set_fill_value(varsncdf['all_min'], fill)
    ma.set_fill_value(varsncdf['all_measures'], fill)

    varsncdf['all_median'] = varsncdf['all_median'].filled()
    varsncdf['all_mean'] = varsncdf['all_mean'].filled()
    varsncdf['all_max'] = varsncdf['all_max'].filled()
    varsncdf['all_min'] = varsncdf['all_min'].filled()
    varsncdf['all_measures'] = varsncdf['all_measures'].filled()

    if sensors:
        for key in varcategories.keys():

            varsncdf[key +'_profiles'] = dataclim.createVariable(key + '_profiles', np.int32, ('t', 'z', 'y', 'x'), fill_value=0)

            varsncdf[key + '_median'] = dataclim.createVariable(key + '_median', np.float32, ('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_mean'] = dataclim.createVariable(key + '_mean', np.float32, ('t', 'z', 'y', 'x'),fill_value=np.nan)
            varsncdf[key + '_max'] = dataclim.createVariable(key + '_max', np.float32,('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_min'] = dataclim.createVariable(key + '_min', np.float32,('t', 'z', 'y', 'x'), fill_value=np.nan)
            varsncdf[key + '_measures'] = dataclim.createVariable(key + '_measures', np.float32, ('t', 'z', 'y', 'x'),fill_value=np.nan)

            if ismask == 1:
                varsncdf[key+'_median'][:, :, :, :] = maskarray
                varsncdf[key + '_mean'][:, :, :, :] = maskarray
                varsncdf[key + '_max'][:, :, :, :] = maskarray
                varsncdf[key + '_min'][:, :, :, :] = maskarray
                varsncdf[key + '_measures'][:, :, :, :] = maskarray

            for dictkey in dict[key+'month'].keys():
                [a, b, c, d] = [int(i) for i in dictkey.split('-')]
                varsncdf[key+'_median'][a, b, c, d] = median(dict[key+'month'][dictkey])
                varsncdf[key + '_mean'][a, b, c, d] = mean(dict[key + 'month'][dictkey])
                varsncdf[key + '_max'][a, b, c, d] = max(dict[key + 'month'][dictkey])
                varsncdf[key + '_min'][a, b, c, d] = min(dict[key + 'month'][dictkey])
                varsncdf[key + '_measures'][a, b, c, d] = len(dict[key + 'month'][dictkey])

    for mnth in range(12):
        vars['mnthprofilesall']=vars['profilesallnew'][monthinds[mnth],:,:,:]
        varsncdf['all_profiles'][mnth,:,:,:]=np.sum(vars['mnthprofilesall'],axis=0)

        if sensors:
            for key in varcategories.keys():
                vars['mnthprofiles'+key] = vars['profiles'+key+'new'][monthinds[mnth], :, :, :]
                varsncdf[key + '_profiles'][mnth, :, :, :] = np.sum(vars['mnthprofiles'+key], axis=0)

    latitude=dataclim.createVariable('nav_lat', np.float32, ('y','x'), fill_value=np.nan)
    latitude[:,:] = gridlats
    latitude.axis = 'x'
    longitude = dataclim.createVariable('nav_lon', np.float32, ('y', 'x'), fill_value=np.nan)
    longitude[:,:] = gridlons
    longitude.axis = 'y'
    level = dataclim.createVariable('nav_lev', np.float32, ('z',), fill_value=np.nan)
    level[:] = gridlvls
    level.axis = 'z'
    times = dataclim.createVariable('times', np.int32, ('t',))
    times[:] = range(1,13)
    times.axis = 't'

    return datanew, dataclim

### Choose source and destination directories

### bbp700
# pathin='/gpfs/scratch/bsc32/bsc32786/bgcargo/testfiles/bbp700/' # testing
# pathout='/gpfs/scratch/bsc32/bsc32786/bgcargo/climatologies/'
#
# pathin='/esarchive/obs/argo/bgc/daily/bbp700/'    # all data
# pathout='/esarchive/obs/argo/bgc/climatologies/'

### chla
#pathin='/gpfs/scratch/bsc32/bsc32786/bgcargo/testfiles/chla/' # testing
#pathout='/gpfs/scratch/bsc32/bsc32786/bgcargo/climatologies/'

pathin='/esarchive/obs/argo/bgc/daily/chla/'    # all data
pathout='/esarchive/obs/argo/bgc/climatologies/'

### Choose ocean model
#model='nemo'
model='pisces'

### Choose which grid to use. So far only works for pisces and nemo outputs
map='/esarchive/scratch/mgalitap/aumont/pisces-v2-aumont17/PISCES_1m_19600101_19601231_ptrc_T.nc' # which grid is being used
#map='/esarchive/obs/argo/bgc/climatologies/mesh_mask_nemo.Ec3.2_O1L75.nc'

### Choose a file based on the metadata (for generating results based on different sensors)
sensordata='/esarchive/obs/argo/bgc/sensors_meta.csv'

### choose to places zeros where land is
bathymetry=1

#ts=make_ts(pathin,pathout,map,model,'bbp700',sensordata,'BBP700_CAT')
ts=make_ts(pathin,pathout,map,model,'chla')